"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const defaultGroups = [["^@\\w", "^\\w"], ["^\\.\\./", "^\\./"], ["\\.s?css$"]];
const sortByMemberType = (i1, i2) => {
    const compareHasNamespaceMember = Number(!!i1.namespaceMember) - Number(!!i2.namespaceMember);
    if (compareHasNamespaceMember != 0) {
        return compareHasNamespaceMember;
    }
    const compareHasDefaultMember = Number(!!i1.defaultMember) - Number(!!i2.defaultMember);
    if (compareHasDefaultMember != 0) {
        return compareHasDefaultMember;
    }
    const compareHasNamedMembers = Number(i1.namedMembers.length > 0) - Number(i2.namedMembers.length > 0);
    return compareHasNamedMembers;
};
const Index = (styleApi, _file, options) => {
    const groups = options?.groups || defaultGroups;
    const { and, unicode, moduleName, member, name, hasNoMember, isAbsoluteModule, isRelativeModule } = styleApi;
    return [
        { match: and(hasNoMember, isAbsoluteModule) },
        { separator: true },
        { match: and(hasNoMember, isRelativeModule) },
        { separator: true },
        ...groups.flatMap((group) => [
            ...group.map((regex) => {
                const match = (i) => Boolean(new RegExp(regex).exec(i.moduleName));
                return {
                    match,
                    sort: [sortByMemberType, moduleName(unicode), member(unicode)],
                    sortNamedMembers: name(unicode),
                };
            }),
            { separator: true },
        ]),
    ];
};
exports.default = Index;
